@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-09-02 10:48:07
+@LastEditTime: 2021-09-03 10:47:19
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -739,10 +739,6 @@ class PropGiveListHandler(SevenBaseHandler):
         :param page_index：页索引
         :param page_size：页大小
         :param act_id：活动id
-        :param user_open_id：赠送人open_id
-        :param nick_name：赠送人淘宝名
-        :param draw_open_id：领取人open_id
-        :param draw_nick_name：领取人淘宝名
         :param start_date：开始时间
         :param end_date：结束时间
         :param give_status：赠送状态(0未领取1已领取2已失效)
@@ -752,32 +748,19 @@ class PropGiveListHandler(SevenBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
         act_id = int(self.get_param("act_id", 0))
-        user_nick = self.get_param("nick_name")
-        user_open_id = self.get_param("user_open_id")
-        draw_user_nick = self.get_param("draw_nick_name")
-        draw_open_id = self.get_param("draw_open_id")
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
         give_status = int(self.get_param("give_status", -1))
-
+        open_id = self.get_taobao_param().open_id
         condition = "act_id=%s"
         params = [act_id]
 
         if give_status >= 0:
             condition += " AND give_status=%s"
             params.append(give_status)
-        if user_open_id:
+        if open_id:
             condition += " AND open_id=%s"
-            params.append(user_open_id)
-        if user_nick:
-            condition += " AND user_nick=%s"
-            params.append(user_nick)
-        if draw_open_id:
-            condition += " AND draw_open_id=%s"
-            params.append(draw_open_id)
-        if draw_user_nick:
-            condition += " AND draw_user_nick=%s"
-            params.append(draw_user_nick)
+            params.append(open_id)
         if start_date:
             condition += " AND create_date>=%s"
             params.append(start_date)
